@@ -8,7 +8,7 @@ from scipy.fftpack import fft
 __all__ = ['boxcar', 'triang', 'parzen', 'bohman', 'blackman', 'nuttall',
            'blackmanharris', 'flattop', 'bartlett', 'hanning', 'barthann',
            'hamming', 'kaiser', 'gaussian', 'general_gaussian', 'chebwin',
-           'slepian', 'hann', 'get_window']
+           'slepian', 'cosine', 'hann', 'get_window']
 
 
 def boxcar(M, sym=True):
@@ -27,7 +27,7 @@ def boxcar(M, sym=True):
     Returns
     -------
     w : ndarray
-        The window, with the maximum value normalized to 1
+        The window, with the maximum value normalized to 1.
 
     Examples
     --------
@@ -66,14 +66,15 @@ def triang(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -129,14 +130,15 @@ def parzen(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -191,14 +193,15 @@ def bohman(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -241,13 +244,13 @@ def bohman(M, sym=True):
 
 
 def blackman(M, sym=True):
-    """
+    r"""
     Return a Blackman window.
 
-    The Blackman window is a taper formed by using the the first three
-    terms of a summation of cosines. It was designed to have close to the
-    minimal leakage possible.  It is close to optimal, only slightly worse
-    than a Kaiser window.
+    The Blackman window is a taper formed by using the first three terms of
+    a summation of cosines. It was designed to have close to the minimal
+    leakage possible.  It is close to optimal, only slightly worse than a
+    Kaiser window.
 
     Parameters
     ----------
@@ -255,20 +258,21 @@ def blackman(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Notes
     -----
     The Blackman window is defined as
 
-    .. math::  w(n) = 0.42 - 0.5 \\cos(2\\pi n/M) + 0.08 \\cos(4\\pi n/M)
+    .. math::  w(n) = 0.42 - 0.5 \cos(2\pi n/M) + 0.08 \cos(4\pi n/M)
 
     Most references to the Blackman window come from the signal processing
     literature, where it is used as one of many windowing functions for
@@ -335,14 +339,15 @@ def nuttall(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -395,14 +400,15 @@ def blackmanharris(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -455,14 +461,15 @@ def flattop(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -508,7 +515,7 @@ def flattop(M, sym=True):
 
 
 def bartlett(M, sym=True):
-    """
+    r"""
     Return a Bartlett window.
 
     The Bartlett window is very similar to a triangular window, except
@@ -522,23 +529,24 @@ def bartlett(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
-        The triangular window, with the maximum value normalized to 1
-        (though the value 1 does not appear if the number of samples is even
-        and sym is True), with the first and last samples equal to zero.
+        The triangular window, with the first and last samples equal to zero
+        and the maximum value normalized to 1 (though the value 1 does not
+        appear if `M` is even and `sym` is True).
 
     Notes
     -----
     The Bartlett window is defined as
 
-    .. math:: w(n) = \\frac{2}{M-1} \\left(
-              \\frac{M-1}{2} - \\left|n - \\frac{M-1}{2}\\right|
-              \\right)
+    .. math:: w(n) = \frac{2}{M-1} \left(
+              \frac{M-1}{2} - \left|n - \frac{M-1}{2}\right|
+              \right)
 
     Most references to the Bartlett window come from the signal
     processing literature, where it is used as one of many windowing
@@ -546,7 +554,7 @@ def bartlett(M, sym=True):
     window produces linear interpolation.  It is also known as an
     apodization (which means"removing the foot", i.e. smoothing
     discontinuities at the beginning and end of the sampled signal) or
-    tapering function. The fourier transform of the Bartlett is the product
+    tapering function. The Fourier transform of the Bartlett is the product
     of two sinc functions.
     Note the excellent discussion in Kanasewich.
 
@@ -605,7 +613,7 @@ def bartlett(M, sym=True):
 
 
 def hann(M, sym=True):
-    """
+    r"""
     Return a Hann window.
 
     The Hann window is a taper formed by using a raised cosine or sine-squared
@@ -617,7 +625,8 @@ def hann(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
@@ -630,10 +639,10 @@ def hann(M, sym=True):
     -----
     The Hann window is defined as
 
-    .. math::  w(n) = 0.5 - 0.5 \\cos\\left(\\frac{2\\pi{n}}{M-1}\\right)
-               \\qquad 0 \\leq n \\leq M-1
+    .. math::  w(n) = 0.5 - 0.5 \cos\left(\frac{2\pi{n}}{M-1}\right)
+               \qquad 0 \leq n \leq M-1
 
-    The window was named for Julius van Hann, an Austrian meterologist. It is
+    The window was named for Julius van Hann, an Austrian meteorologist. It is
     also known as the Cosine Bell. It is sometimes erroneously referred to as
     the "Hanning" window, from the use of "hann" as a verb in the original
     paper and confusion with the very similar Hamming window.
@@ -706,14 +715,15 @@ def barthann(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Examples
     --------
@@ -767,14 +777,15 @@ def hamming(M, sym=True):
         Number of points in the output window. If zero or less, an empty
         array is returned.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Notes
     -----
@@ -857,14 +868,15 @@ def kaiser(M, beta, sym=True):
         Shape parameter, determines trade-off between main-lobe width and
         side lobe level. As beta gets large, the window narrows.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Notes
     -----
@@ -972,14 +984,15 @@ def gaussian(M, std, sym=True):
     std : float
         The standard deviation, sigma.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Notes
     -----
@@ -1041,14 +1054,15 @@ def general_gaussian(M, p, sig, sym=True):
     sig : float
         The standard deviation, sigma.
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
     -------
     w : ndarray
         The window, with the maximum value normalized to 1 (though the value 1
-        does not appear if the number of samples is even and sym is True).
+        does not appear if `M` is even and `sym` is True).
 
     Notes
     -----
@@ -1102,7 +1116,7 @@ def general_gaussian(M, p, sig, sym=True):
 # `chebwin` contributed by Kumar Appaiah.
 
 def chebwin(M, at, sym=True):
-    """Return a Dolph-Chebyshev window.
+    r"""Return a Dolph-Chebyshev window.
 
     Parameters
     ----------
@@ -1112,7 +1126,8 @@ def chebwin(M, at, sym=True):
     at : float
         Attenuation (in dB).
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
@@ -1120,6 +1135,46 @@ def chebwin(M, at, sym=True):
     w : ndarray
         The window, with the maximum value always normalized to 1
 
+    Notes
+    -----
+    This window optimizes for the narrowest main lobe width for a given order
+    `M` and sidelobe equiripple attenuation `at`, using Chebyshev
+    polynomials.  It was originally developed by Dolph to optimize the
+    directionality of radio antenna arrays.
+
+    Unlike most windows, the Dolph-Chebyshev is defined in terms of its
+    frequency response:
+
+    .. math:: W(k) = \frac
+              {\cos\{M \cos^{-1}[\beta \cos(\frac{\pi k}{M})]\}}
+              {\cosh[M \cosh^{-1}(\beta)]}
+
+    where
+
+    .. math:: \beta = \cosh \left [\frac{1}{M}
+              \cosh^{-1}(10^\frac{A}{20}) \right ]
+
+    and 0 <= abs(k) <= M-1. A is the attenuation in decibels (`at`).
+
+    The time domain window is then generated using the IFFT, so
+    power-of-two `M` are the fastest to generate, and prime number `M` are
+    the slowest.
+
+    The equiripple condition in the frequency domain creates impulses in the
+    time domain, which appear at the ends of the window.
+
+    References
+    ----------
+    .. [1] C. Dolph, "A current distribution for broadside arrays which
+           optimizes the relationship between beam width and side-lobe level",
+           Proceedings of the IEEE, Vol. 34, Issue 6
+    .. [2] Peter Lynch, "The Dolph-Chebyshev Window: A Simple Optimal Filter",
+           American Meteorological Society (April 1997)
+           http://mathsci.ucd.ie/~plynch/Publications/Dolph.pdf
+    .. [3] F. J. Harris, "On the use of windows for harmonic analysis with the
+           discrete Fourier transforms", Proceedings of the IEEE, Vol. 66,
+           No. 1, January 1978
+
     Examples
     --------
     Plot the window and its frequency response:
@@ -1186,7 +1241,7 @@ def chebwin(M, at, sym=True):
 
 
 def slepian(M, width, sym=True):
-    """Return a digital Slepian window.
+    """Return a digital Slepian (DPSS) window.
 
     Used to maximize the energy concentration in the main lobe.  Also called
     the digital prolate spheroidal sequence (DPSS).
@@ -1199,7 +1254,8 @@ def slepian(M, width, sym=True):
     width : float
         Bandwidth
     sym : bool, optional
-        When True, generates a symmetric window, for use in filter design.
+        When True (default), generates a symmetric window, for use in filter
+        design.
         When False, generates a periodic window, for use in spectral analysis.
 
     Returns
@@ -1233,7 +1289,7 @@ def slepian(M, width, sym=True):
 
     """
     if (M * width > 27.38):
-        raise ValueError("Cannot reliably obtain slepian sequences for"
+        raise ValueError("Cannot reliably obtain Slepian sequences for"
               " M*width > 27.38.")
     if M < 1:
         return np.array([])
@@ -1259,6 +1315,68 @@ def slepian(M, width, sym=True):
     return w
 
 
+def cosine(M, sym=True):
+    """Return a window with a simple cosine shape.
+
+    .. versionadded:: 0.13.0
+
+    Parameters
+    ----------
+    M : int
+        Number of points in the output window. If zero or less, an empty
+        array is returned.
+    sym : bool, optional
+        When True (default), generates a symmetric window, for use in filter
+        design.
+        When False, generates a periodic window, for use in spectral analysis.
+
+    Returns
+    -------
+    w : ndarray
+        The window, with the maximum value normalized to 1 (though the value 1
+        does not appear if `M` is even and `sym` is True).
+
+    Examples
+    --------
+    Plot the window and its frequency response:
+
+    >>> from scipy import signal
+    >>> from scipy.fftpack import fft, fftshift
+    >>> import matplotlib.pyplot as plt
+
+    >>> window = signal.cosine(51)
+    >>> plt.plot(window)
+    >>> plt.title("Cosine window")
+    >>> plt.ylabel("Amplitude")
+    >>> plt.xlabel("Sample")
+
+    >>> plt.figure()
+    >>> A = fft(window, 2048) / (len(window)/2.0)
+    >>> freq = np.linspace(-0.5, 0.5, len(A))
+    >>> response = 20 * np.log10(np.abs(fftshift(A / abs(A).max())))
+    >>> plt.plot(freq, response)
+    >>> plt.axis([-0.5, 0.5, -120, 0])
+    >>> plt.title("Frequency response of the cosine window")
+    >>> plt.ylabel("Normalized magnitude [dB]")
+    >>> plt.xlabel("Normalized frequency [cycles per sample]")
+    >>> plt.show()
+
+    """
+    if M < 1:
+        return np.array([])
+    if M == 1:
+        return np.ones(1, 'd')
+    odd = M % 2
+    if not sym and not odd:
+        M = M + 1
+
+    w = np.sin(np.pi / M * (np.arange(0, M) + .5))
+
+    if not sym and not odd:
+        w = w[:-1]
+    return w
+
+
 def get_window(window, Nx, fftbins=True):
     """
     Return a window.
@@ -1368,6 +1486,8 @@ def get_window(window, Nx, fftbins=True):
             winfunc = boxcar
         elif winstr in ['slepian', 'slep', 'optimal', 'dpss', 'dss']:
             winfunc = slepian
+        elif winstr in ['cosine', 'halfcosine']:
+            winfunc = cosine
         elif winstr in ['chebwin', 'cheb']:
             winfunc = chebwin
         else:
