@@ -16,7 +16,7 @@ import sys
 import numpy as np
 import scipy as sp
 
-from scipy.lib.six.moves import xrange
+from scipy.lib.six import xrange
 
 from scipy.sparse.linalg import aslinearoperator, LinearOperator
 
@@ -348,6 +348,11 @@ def lobpcg(A, X,
 
     ##
     # Main iteration loop.
+
+    blockVectorP = None  # set during iteration
+    blockVectorAP = None
+    blockVectorBP = None
+
     for iterationNumber in xrange(maxIterations):
         if verbosityLevel > 0:
             print('iteration %d' % iterationNumber)
