@@ -18,5 +18,8 @@ from ._discrete_distns import *
 
 # For backwards compatibility e.g. pymc expects distributions.__all__.
 __all__ = ['entropy', 'rv_discrete', 'rv_continuous']
-__all__ += _continuous_distns.__all__ + _discrete_distns.__all__
+
+# Add only the distribution names, not the *_gen names.
+__all__ += _continuous_distns._distn_names
+__all__ += _discrete_distns._distn_names
 
